@@ -14,9 +14,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import platform
+
+import pytest
+
 from .. import __version__
 
 
+@pytest.mark.skipif(platform.system() == "Windows", reason="no capture on win")
 def test_cli_version(script_runner):
     ret = script_runner.run("jupyter", "ipydrawio-export", "--version")
     assert ret.success
